@@ -9,7 +9,7 @@ eval 'exec /usr/bin/perl  -S $0 ${1+"$@"}'
 #
 #   Net::FullAuto is powerful network process automation
 #   software that has been in un-released development for
-#   more than seven years. For this reason, you may find
+#   more than eleven years. For this reason, you may find
 #   it to be useful for many process automation projects.
 #   Because it has been worked on for so long, it may appear
 #   to work well, and pass a number of non-intensive tests.
@@ -29,6 +29,9 @@ eval 'exec /usr/bin/perl  -S $0 ${1+"$@"}'
 #
 ################################################################
 
+use strict;
+use warnings;
+
 BEGIN {
 
    my $edit=0;my $earg='';my $cnt=0;
